@@ -371,15 +371,12 @@ DBgetXY <- function (states = NULL,
   ## GETS DATA TABLES (OTHER THAN PLOT/CONDITION) IF NULL
   ###########################################################
   if (gui) {
-    Typelst <- c("CURR", "VOL", "P2VEG", "DWM", "GRM")
+    Typelst <- c("ALL", "CURR", "VOL", "P2VEG", "DWM", "INV", "GROW", "MORT", "REMV", "GRM")
     Type <- select.list(Typelst, title="eval type", 
 		preselect="VOL", multiple=TRUE)
     if (length(Type)==0) Type <- "VOL"
   } 
 
-  if (any(Type == "VOL")) {
-    istree=isseed <- TRUE
-  } 
   if (any(Type == "P2VEG")) {
     # understory vegetation tables 
     # (P2VEG_SUBPLOT_SPP, P2VEG_SUBP_STRUCTURE, INVASIVE_SUBPLOT_SPP)
@@ -436,7 +433,7 @@ DBgetXY <- function (states = NULL,
   ## Get states, Evalid and/or invyrs info
   ##########################################################
   if (!is.null(evalInfo)) {
-    list.items <- c("states", "evalidlist", "invtype", "invyrtab")
+    list.items <- c("states", "invtype", "invyrtab")
     evalInfo <- pcheck.object(evalInfo, "evalInfo", list.items=list.items)
 
   } else {
@@ -484,7 +481,7 @@ DBgetXY <- function (states = NULL,
     PLOT <- evalInfo$PLOT
     plotnm <- "PLOT"
   }
-
+ 
   if (!is.null(POP_PLOT_STRATUM_ASSGN)) {
     ppsanm <- "POP_PLOT_STRATUM_ASSGN"
   } else if (!is.null(evalInfo$POP_PLOT_STRATUM_ASSGN)) {
@@ -525,6 +522,9 @@ DBgetXY <- function (states = NULL,
   }
   pvars2keep <- unique(c("STATECD", "UNITCD", "COUNTYCD", "PLOT", 
 					pvars2keep))
+  if (!iseval) {
+    pvars2keep <- unique(pvars2keep, "SRV_CN")
+  }    
 
   if (!is.null(measyrs) || measCur) {
     XYvarlst <- unique(c(XYvarlst, "MEASYEAR", "PLOT_STATUS_CD", "INVYR")) 
@@ -580,6 +580,17 @@ DBgetXY <- function (states = NULL,
       stop(xy, " does not exist in database\n ", toString(xytablst))
     }
   } else {
+    if (iseval && is.null(POP_PLOT_STRATUM_ASSGN)) {
+      ppsaqry <- paste("select * from POP_PLOT_STRATUM_ASSGN where evalid IN(",
+               toString(unlist(evalidlist)), ")")
+			
+      POP_PLOT_STRATUM_ASSGN <- tryCatch( DBI::dbGetQuery(dbconn, ppsaqry),
+			error = function(e) {
+                  message(e, "\n")
+                  return(NULL) })
+      ppsanm <- "POP_PLOT_STRATUM_ASSGN"
+    }
+
     XYdf <- pcheck.table(xy, stopifnull=TRUE, stopifinvalid=TRUE)
     xynm <- "XYdf"
     names(XYdf) <- toupper(names(XYdf))
@@ -913,14 +924,18 @@ DBgetXY <- function (states = NULL,
         pnm <- plotnm
         pid <- xyjoinid
       }
-      popSURVEY <- ifelse(is.null(SURVEY), FALSE, TRUE)
+      popSURVEY <- FALSE
+      if (!is.null(SURVEY) && "SRV_CN" %in% names(get(pnm))) {
+        popSURVEY <- TRUE
+      }
+        
       pfromqry <- getpfromqry(Endyr = measEndyr, 
                             SCHEMA. = SCHEMA., 
                             intensity1 = intensity1, 
                             popSURVEY = popSURVEY, 
                             plotnm = pnm,
                             pjoinid = pid,
-                            surveynm = "SURVEY",
+                            surveynm = surveynm,
                             plotobj = get(pnm))
       if (xyisplot || is.null(plotnm)) {
         xyfromqry <- pfromqry
@@ -1028,7 +1043,7 @@ DBgetXY <- function (states = NULL,
     xyx <- tryCatch( sqldf::sqldf(xycoords.qry, 
 						stringsAsFactors = FALSE), 
 			error = function(e) {
-                  message(e)
+                  message(e, "\n")
                   return(NULL) })
 
     if (!iseval && is.null(invyrtab) && !is.null(invyrtab.qry)) {
