@@ -80,8 +80,11 @@
 #' @param pjoinid String. Join variable in plot to match pltassgnid. Does not
 #' need to be uniqueid. If using most current XY coordinates for plot
 #' assignments, use identifier for plot (e.g., PLOT_ID).
-#' @param areawt String. Name of variable for summarizing area weights (e.g.,
-#' CONDPROP_UNADJ).
+#' @param areawt String. Name of variable in cond for summarizing area 
+#' weights (e.g., CONDPROP_UNADJ).
+#' @param areawt2 String. An equation to multiply to areawt for estimation. 
+#' All variables in equation must be in cond.
+#' weights (e.g., CONDPROP_UNADJ).
 #' @param adj String. How to calculate adjustment factors for nonsampled
 #' (nonresponse) conditions based on summed proportions for by plot ('samp',
 #' 'plot').  'samp' - adjustments are calculated at strata/estimation unit
@@ -244,6 +247,7 @@ modGBpop <- function(popType = "VOL",
                      dsn = NULL, 
                      pjoinid = "CN", 
                      areawt = "CONDPROP_UNADJ", 
+                     areawt2 = NULL,
                      adj = "samp", 
                      unitvar = NULL, 
                      unitarea = NULL, 
@@ -485,7 +489,6 @@ modGBpop <- function(popType = "VOL",
 		overwrite=overwrite_layer, outfn.pre=outfn.pre, outfn.date=outfn.date)
   }
 
-
   ## Check popType
   ########################################################
   #evalTyplst <- c("ALL", "CURR", "VOL", "LULC", "P2VEG", "INV", "GRM", "DWM")
@@ -500,7 +503,7 @@ modGBpop <- function(popType = "VOL",
     evalid <- as.character(evalid)
     substr(evalid, nchar(evalid)-1, nchar(evalid)) <- "01"
   } 
-
+ 
  
   ###################################################################################
   ## Load data
@@ -615,14 +618,19 @@ modGBpop <- function(popType = "VOL",
     stop("need to include popTabs")
   }
 
-  list.items <- {}
+  list.items <- c("cond")
+  if (popType == "VOL") {
+    list.items <- c(list.items, "tree")
+  }
   if (popType == "P2VEG") {
     list.items <- c(list.items, "vsubpstr", "subplot", "subp_cond")
   }
   if (popType == "DWM") {
     list.items <- c(list.items, "cond_dwm_calc")
   }
-
+  if (popType == "CHNG") {
+    list.items <- c(list.items, "sccm")
+  }
   popTabs <- pcheck.object(popTabs, "popTabs", list.items=list.items)
 
   ## Set user-supplied popTabIDs values
@@ -685,7 +693,7 @@ modGBpop <- function(popType = "VOL",
     nfplotsampcnt <- pltcheck$nfplotsampcnt
   }
  
-  if (popType %in% c("ALL", "CURR", "AREA", "VOL")) {
+  if (popType %in% c("ALL", "CURR", "VOL")) {
     ###################################################################################
     ## Check parameters and data for popType AREA/VOL
     ###################################################################################
@@ -693,7 +701,7 @@ modGBpop <- function(popType = "VOL",
                tabs=popTabs, tabIDs=popTabIDs, pltassgnx=pltassgnx, 
                pfromqry=pfromqry, palias=palias, pjoinid=pjoinid, whereqry=whereqry, 
                adj=adj, ACI=ACI, pltx=pltx, puniqueid=puniqueid, dsn=dsn, dbconn=dbconn,
-               condid="CONDID", nonsamp.cfilter=nonsamp.cfilter)
+               condid="CONDID", nonsamp.cfilter=nonsamp.cfilter, areawt=areawt, areawt2=areawt2)
     if (is.null(popcheck)) return(NULL)
     condx <- popcheck$condx
     pltcondx <- popcheck$pltcondx
@@ -705,6 +713,7 @@ modGBpop <- function(popType = "VOL",
     ACI.filter <- popcheck$ACI.filter
     condsampcnt <- popcheck$condsampcnt
     areawt <- popcheck$areawt
+    areawt2 <- popcheck$areawt2
     tpropvars <- popcheck$tpropvars
   }
  
@@ -712,13 +721,13 @@ modGBpop <- function(popType = "VOL",
     ###################################################################################
     ## Check parameters and data for popType AREA/VOL
     ###################################################################################
-    popcheck <- check.popdataCHNG(gui=gui, 
+    popcheck <- check.popdataCHNG(gui=gui, popType=popType,
                tabs=popTabs, tabIDs=popTabIDs, pltassgnx=pltassgnx, 
                pfromqry=pfromqry, palias=palias, pjoinid=pjoinid, whereqry=whereqry, 
                adj=adj, ACI=ACI, pltx=pltx, puniqueid=puniqueid, dsn=dsn, dbconn=dbconn,
                condid="CONDID", nonsamp.cfilter=nonsamp.cfilter, cvars2keep="REMPER")
     if (is.null(popcheck)) return(NULL)
-    condx <- popcheck$condx
+    condx <- popcheck$sccm_condx
     sccmx <- popcheck$sccmx
     pltcondx <- popcheck$pltcondx
     treef <- popcheck$treef
@@ -779,7 +788,7 @@ modGBpop <- function(popType = "VOL",
 #  if (popType == "LULC") {
 #    lulcx <- popcheck$lulcx
 #  }
- 
+
   ###################################################################################
   ## CHECK STRATA
   ###################################################################################
@@ -823,7 +832,7 @@ modGBpop <- function(popType = "VOL",
   ##     by strata and estunit (*PROP_UNADJ_SUM / n.strata)
   ##  2. Adjusted condition proportion (CONDPROP_ADJ) appended to condx
   ###################################################################################
-
+ 
   ## Merge plot strata info to condx
   if (is.null(key(condx))) setkeyv(condx, c(cuniqueid, condid))
   condx <- condx[pltassgnx[,c(pltassgnid, strunitvars), with=FALSE]]
@@ -839,9 +848,7 @@ modGBpop <- function(popType = "VOL",
     areawtnm <- areawt
 
   } else {
-    if (popType %in% c("ALL", "VOL", "CURR", "CHNG")) {
-      if (popType == "CHNG") areawt <- "SUBPTYP_PROP_CHNG"
-
+    if (popType %in% c("ALL", "VOL", "CURR")) {
       adjfacdata <- getadjfactorVOL(adj=adj, 
                         condx = condx, 
                         treex = treef, 
@@ -861,11 +868,32 @@ modGBpop <- function(popType = "VOL",
       areaadj <- adjfacdata$areaadj
       varadjlst <- adjfacdata$varadjlst
       areawtnm <- adjfacdata$areawtnm
-      stratalut <- adjfacdata$unitlut
+      #stratalut <- adjfacdata$unitlut
       expcondtab <- adjfacdata$expcondtab
     }
 
     if (popType == "CHNG") {
+
+      adjfacdata <- getadjfactorVOL(adj=adj, 
+                        condx = condx, 
+                        #treex = treef, 
+                        #seedx = seedf, 
+                        cuniqueid = cuniqueid, 
+                        condid = condid,
+                        unitlut = stratalut, 
+                        unitvars = unitvar,
+                        strvars = strvar,
+                        unitarea = unitarea,
+                        areavar = areavar, 
+                        areawt = areawt
+                        )
+      condx <- adjfacdata$condx
+      areaadj <- adjfacdata$areaadj
+      varadjlst <- adjfacdata$varadjlst
+      areawtnm <- adjfacdata$areawtnm
+      stratalut <- adjfacdata$unitlut
+      expcondtab <- adjfacdata$expcondtab
+
       strunitvars <- key(stratalut)
       if (is.null(key(sccmx))) setkeyv(sccmx, c(cuniqueid, condid))
       sccmx <- sccmx[pltassgnx[,c(pltassgnid, strunitvars), with=FALSE]]
@@ -947,7 +975,15 @@ modGBpop <- function(popType = "VOL",
   ###################################################################################
   ## Return population data objects
   ###################################################################################
-  estvar.area <- ifelse(adj == "none", "CONDPROP_UNADJ", "CONDPROP_ADJ")
+
+  if (!is.null(areawt2)) {
+    if (!is.numeric(condx[[areawt2]])) {
+      stop("areawt2 is invalid")
+    }
+    condx$areawt <- condx[[areawtnm]] * condx[[areawt2]]
+    areawtnm <- "areawt"
+  } 
+
   returnlst$popType <- popType
   if (!is.null(bndx)) {
     returnlst$bndx <- bndx
@@ -965,8 +1001,8 @@ modGBpop <- function(popType = "VOL",
             strata=strata, stratalut=data.table(stratalut), 
             strvar=strvar, strwtvar=strwtvar, expcondtab=expcondtab, 
             plotsampcnt=plotsampcnt, condsampcnt=condsampcnt, 
-            states=states, invyrs=invyrs, estvar.area=estvar.area, 
-            adj=adj, areawt=areawtnm, P2POINTCNT=P2POINTCNT))
+            states=states, invyrs=invyrs, estvar.area=areawtnm, 
+            adj=adj, P2POINTCNT=P2POINTCNT))
 
   if (popType == "VOL") {
     if (!is.null(treef)) {
