@@ -34,16 +34,16 @@
 #' @param subp_cond DF/DT, R object, comma-delimited file(*.csv), or layer in
 #' dsn. Subplot condition-level data with one record for each species
 #' (SUBP_COND).
-#' @param cond_dwm_calc DF/DT, R object, comma-delimited file(*.csv), or layer 
+#' @param dwm DF/DT, R object, comma-delimited file(*.csv), or layer 
 #' in dsn. Calculated down woody material.
 #' @param sccm DF/DT, R object, comma-delimited file(*.csv), or layer in dsn.
 #' Subplot-level data (SUBP_COND_CHNG_MTRX).
 #' @param grm DF/DT, R object, comma-delimited file(*.csv), or layer in dsn.
 #' Tree-level growth, removal, and mortality data (TREE_GRM_COMPONENT).
-#' @param plot_pplot DF/DT, R object, comma-delimited file(*.csv), or layer in dsn.
-#' Plot-level data with previous and current plots.
-#' @param cond_pcond DF/DT, R object, comma-delimited file(*.csv), or layer in dsn.
-#' Condition-level data with previous and current plots.
+#' @param pltu DF/DT, R object, comma-delimited file(*.csv), or layer in dsn.
+#' Plot-level data with unioned previous and current plots.
+#' @param condu DF/DT, R object, comma-delimited file(*.csv), or layer in dsn.
+#' Condition-level data with unioned previous and current plots.
 #' @param ... For extendibility.
 #' @return A list of user-supplied parameters and parameter values for strata.
 #' @author Grayson W. White
@@ -61,11 +61,11 @@ popTables <- function(cond = NULL,
                       invsubp = NULL,
                       subplot = NULL, 
                       subp_cond = NULL, 
-                      cond_dwm_calc = NULL,
+                      dwm = NULL,
                       sccm = NULL,
                       grm = NULL,
-                      plot_pplot = NULL, 
-                      cond_pcond = NULL, 
+                      pltu = NULL, 
+                      condu = NULL, 
                       ...) {
   # Check input parameters
   input.params <- names(as.list(match.call()))[-1]
